import { GridTabulator, defaultGridTabulatorConfig, gridTabulatorShadowOptions, } from '@genesislcap/grid-tabulator';
import { zeroGridTabulatorStyles as styles } from './grid-tabulator.styles';
import { zeroGridTabulatorTemplate as template } from './grid-tabulator.template';
import { themeGenesisRapidDarkName, themeGenesisRapidName } from './themes';
const defaultRowHeaderHeight = 40;
const defaultRapidTheme = 'tabulator-theme-genesis-rapid-dark';
/**
 * @tagname %%prefix%%-grid-tabulator
 */
export class ZeroGridTabulator extends GridTabulator {
    constructor() {
        super(...arguments);
        /**
         * Sets default theme to Rapid
         * @override
         */
        this.theme = defaultRapidTheme;
    }
    themeChanged(oldValue, newValue) {
        if (!oldValue && newValue !== defaultRapidTheme)
            return;
        super.themeChanged(oldValue, newValue);
    }
    /**
     * Handles extra ZERO configs
     * @override
     */
    set gridOptions(options) {
        // options.components = {
        //   [GridTabulatorRendererTypes.action]: ZeroAgActionRenderer,
        //   [GridTabulatorRendererTypes.actionsMenu]: ZeroAgActionsMenuRenderer,
        //   [GridTabulatorRendererTypes.boolean]: ZeroBooleanRenderer,
        // };
        var _a;
        const isRapidTheme = this.theme === themeGenesisRapidName || this.theme === themeGenesisRapidDarkName;
        if (isRapidTheme) {
            // this.headerHeight = options.headerHeight ?? defaultRowHeaderHeight;
            this.rowHeight = (_a = options.rowHeight) !== null && _a !== void 0 ? _a : defaultRowHeaderHeight;
        }
        super.gridOptions = options;
    }
}
// explicitly declaring for extensibility
export const zeroGridTabulatorShadowOptions = gridTabulatorShadowOptions;
export const zeroGridTabulatorDefaultConfig = defaultGridTabulatorConfig;
export const zeroGridTabulator = ZeroGridTabulator.compose(Object.assign({ baseName: 'grid-tabulator', template,
    styles, shadowOptions: zeroGridTabulatorShadowOptions }, zeroGridTabulatorDefaultConfig));
